==> ews-1.0.20.tar.gz: lib/Search/FolderView.dart <==
/*
 * Exchange Web Services Managed API
 *
 * Copyright (c) Microsoft Corporation
 * All rights reserved.
 *
 * MIT License
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this
 * software and associated documentation files (the "Software"), to deal in the Software
 * without restriction, including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons
 * to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED *AS IS*, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

import 'package:ews/Core/EwsServiceXmlWriter.dart';
import 'package:ews/Core/XmlAttributeNames.dart';
import 'package:ews/Core/XmlElementNames.dart';
import 'package:ews/Enumerations/FolderTraversal.dart';
import 'package:ews/Enumerations/OffsetBasePoint.dart';
import 'package:ews/Enumerations/ServiceObjectType.dart';
import 'package:ews/Search/PagedView.dart';

/// <summary>
/// Represents the view settings in a folder search operation.
/// </summary>
class FolderView extends PagedView {
  FolderTraversal _traversal;

  /// <summary>
  /// Gets the name of the view XML element.
  /// </summary>
  /// <returns>XML element name.</returns>
  @override
  String GetViewXmlElementName() {
    return XmlElementNames.IndexedPageFolderView;
  }

  /// <summary>
  /// Gets the type of service object this view applies to.
  /// </summary>
  /// <returns>A ServiceObjectType value.</returns>
  @override
  ServiceObjectType GetServiceObjectType() {
    return ServiceObjectType.Folder;
  }

  /// <summary>
  /// Writes the attributes to XML.
  /// </summary>
  /// <param name="writer">The writer.</param>
  @override
  void WriteAttributesToXml(EwsServiceXmlWriter writer) {
    writer.WriteAttributeValue(XmlAttributeNames.Traversal, this.Traversal);
  }

  /// <summary>
  /// Initializes a new instance of the <see cref="FolderView"/> class.
  /// </summary>
  /// <param name="pageSize">The maximum number of elements the search operation should return.</param>
  FolderView.withPageSize(int pageSize) : super.withPageSize(pageSize);

  /// <summary>
  /// Initializes a new instance of the <see cref="FolderView"/> class.
  /// </summary>
  /// <param name="pageSize">The maximum number of elements the search operation should return.</param>
  /// <param name="offset">The offset of the view from the base point.</param>
  FolderView.withPageSizeAndOffset(int pageSize, int offset)
      : super.withPageSizeAndOffset(pageSize, offset);

  /// <summary>
  /// Initializes a new instance of the <see cref="FolderView"/> class.
  /// </summary>
  /// <param name="pageSize">The maximum number of elements the search operation should return.</param>
  /// <param name="offset">The offset of the view from the base point.</param>
  /// <param name="offsetBasePoint">The base point of the offset.</param>
  FolderView.withPageSizeAndOffsetAndBasePoint(
      int pageSize, int offset, OffsetBasePoint offsetBasePoint)
      : super.withPageSizeAndOffsetAndBasePoint(
            pageSize, offset, offsetBasePoint) {}

  /// <summary>
  /// Gets or sets the search traversal mode. Defaults to FolderTraversal.Shallow.
  /// </summary>
  FolderTraversal get Traversal => this._traversal;

  set Traversal(FolderTraversal value) => this._traversal = value;
}

==> ews-1.2.1.tar.gz: lib/Search/FolderView.dart <==
/*
 * Exchange Web Services Managed API
 *
 * Copyright (c) Microsoft Corporation
 * All rights reserved.
 *
 * MIT License
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this
 * software and associated documentation files (the "Software"), to deal in the Software
 * without restriction, including without limitation the rights to use, copy, modify, merge,
 * publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons
 * to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or
 * substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED *AS IS*, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
 * INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
 * PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
 * OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 * DEALINGS IN THE SOFTWARE.
 */

import 'package:ews/Core/EwsServiceXmlWriter.dart';
import 'package:ews/Core/XmlAttributeNames.dart';
import 'package:ews/Core/XmlElementNames.dart';
import 'package:ews/Enumerations/FolderTraversal.dart';
import 'package:ews/Enumerations/OffsetBasePoint.dart';
import 'package:ews/Enumerations/ServiceObjectType.dart';
import 'package:ews/Search/PagedView.dart';

/// <summary>
/// Represents the view settings in a folder search operation.
/// </summary>
class FolderView extends PagedView {
  FolderTraversal? _traversal;

  /// <summary>
  /// Gets the name of the view XML element.
  /// </summary>
  /// <returns>XML element name.</returns>
  @override
  String GetViewXmlElementName() {
    return XmlElementNames.IndexedPageFolderView;
  }

  /// <summary>
  /// Gets the type of service object this view applies to.
  /// </summary>
  /// <returns>A ServiceObjectType value.</returns>
  @override
  ServiceObjectType GetServiceObjectType() {
    return ServiceObjectType.Folder;
  }

  /// <summary>
  /// Writes the attributes to XML.
  /// </summary>
  /// <param name="writer">The writer.</param>
  @override
  void WriteAttributesToXml(EwsServiceXmlWriter writer) {
    writer.WriteAttributeValue(XmlAttributeNames.Traversal, this.Traversal);
  }

  /// <summary>
  /// Initializes a new instance of the <see cref="FolderView"/> class.
  /// </summary>
  /// <param name="pageSize">The maximum number of elements the search operation should return.</param>
  FolderView.withPageSize(int pageSize) : super.withPageSize(pageSize);

  /// <summary>
  /// Initializes a new instance of the <see cref="FolderView"/> class.
  /// </summary>
  /// <param name="pageSize">The maximum number of elements the search operation should return.</param>
  /// <param name="offset">The offset of the view from the base point.</param>
  FolderView.withPageSizeAndOffset(int pageSize, int offset)
      : super.withPageSizeAndOffset(pageSize, offset);

  /// <summary>
  /// Initializes a new instance of the <see cref="FolderView"/> class.
  /// </summary>
  /// <param name="pageSize">The maximum number of elements the search operation should return.</param>
  /// <param name="offset">The offset of the view from the base point.</param>
  /// <param name="offsetBasePoint">The base point of the offset.</param>
  FolderView.withPageSizeAndOffsetAndBasePoint(
      int pageSize, int offset, OffsetBasePoint offsetBasePoint)
      : super.withPageSizeAndOffsetAndBasePoint(
            pageSize, offset, offsetBasePoint) {}

  /// <summary>
  /// Gets or sets the search traversal mode. Defaults to FolderTraversal.Shallow.
  /// </summary>
  FolderTraversal? get Traversal => this._traversal;

  set Traversal(FolderTraversal? value) => this._traversal = value;
}
